hash

package
v0.0.0-...-9b15d4d Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Aug 26, 2024 License: MIT Imports: 4 Imported by: 0

Documentation

Index

Constants

This section is empty.

Variables

This section is empty.

Functions

This section is empty.

Types

type HMAC

type HMAC struct {
	// contains filtered or unexported fields
}

HMAC is a wrapper around the crypto/hmac package

func NewHMAC

func NewHMAC(key string) HMAC

NewHMAC returns a new HMAC object with the hmac set

func (HMAC) Hash

func (h HMAC) Hash(input string) string

Hash will hash the provided input string using HMAC with the secret key provided on creation of the HMAC object

Jump to